mailr4715 - /1.3/specific_fns/base_class.py


Others Months | Index by Date | Thread Index
>>   [Date Prev] [Date Next] [Thread Prev] [Thread Next]

Header


Content

Posted by edward on January 15, 2008 - 10:52:
Author: bugman
Date: Tue Jan 15 10:52:45 2008
New Revision: 4715

URL: http://svn.gna.org/viewcvs/relax?rev=4715&view=rev
Log:
Updated the return_data() and return_error() base class methods to the new 
relax design.


Modified:
    1.3/specific_fns/base_class.py

Modified: 1.3/specific_fns/base_class.py
URL: 
http://svn.gna.org/viewcvs/relax/1.3/specific_fns/base_class.py?rev=4715&r1=4714&r2=4715&view=diff
==============================================================================
--- 1.3/specific_fns/base_class.py (original)
+++ 1.3/specific_fns/base_class.py Tue Jan 15 10:52:45 2008
@@ -68,16 +68,28 @@
         return False
 
 
-    def return_data(self, run, i):
-        """Function for returning the Ri data structure."""
-
-        return relax_data_store.res[run][i].relax_data
-
-
-    def return_error(self, run, i):
-        """Function for returning the Ri error structure."""
-
-        return relax_data_store.res[run][i].relax_error
+    def return_data(self, spin):
+        """Function for returning the Ri data structure for the given spin.
+
+        @param spin:    The SpinContainer object.
+        @type spin:     SpinContainer instance
+        @return:        The array of relaxation data values.
+        @rtype:         list of float
+        """
+
+        return spin.relax_data
+
+
+    def return_error(self, spin):
+        """Function for returning the Ri error structure for the given spin.
+
+        @param spin:    The SpinContainer object.
+        @type spin:     SpinContainer instance
+        @return:        The array of relaxation data error values.
+        @rtype:         list of float
+        """
+
+        return spin.relax_error
 
 
     def return_value(self, spin, param, sim=None):




Related Messages


Powered by MHonArc, Updated Tue Jan 15 11:00:16 2008